.. :changelog:

History
-------

0.3.0 (2014-09-15)
++++++++++++++++++

* Add icon when plugin is used in text plugin.
* Switch to djangocms-helper for tests.
* Officially supports python 3.


0.2.0 (2014-04-21)
++++++++++++++++++

* Support for django CMS 3 final.

0.1.0 (2014-02-02)
++++++++++++++++++

* First release on PyPI.